@@ -7,12 +7,19 @@ apply.break <- function(direction,
                         cue.class
 ) {
 
+  testthat::expect_true(direction %in% c("!=", "=", "<", "<=", ">", ">="))
+  testthat::expect_true(length(threshold.val) == 1)
+
+  # direction = cue_direction_new
+  # threshold.val = cue_threshold_new
+  # cue.v = data_current[[cues_name_new]]
+  # cue.class = cue_class_new
+  #
 
   if(is.character(threshold.val)) {threshold.val <- unlist(strsplit(threshold.val, ","))}
 
   if(cue.class %in% c("numeric", "integer")) {threshold.val <- as.numeric(threshold.val)}
 
-
   if(direction == "!=") {output <- (cue.v %in% threshold.val) == FALSE}
   if(direction == "=") {output <- cue.v %in% threshold.val}
   if(direction == "<") {output <- cue.v < threshold.val}
@@ -37,7 +44,7 @@ cost.cues.append <- function(formula,
   data_mf <- model.frame(formula = formula,
                          data = data)
 
-  cue_df <- data_mf[,2:ncol(data_mf)]
+  cue_df <- data_mf[,2:ncol(data_mf), drop = FALSE]
   cue_name_v <- names(cue_df)
 
 
@@ -155,15 +162,13 @@ comp.pred <- function(formula,
                       algorithm = NULL,
                       model = NULL,
                       new.factors = "exclude") {
-
-
-  #
-  #   formula = formula
-  #   data.train = data.train
-  #   data.test = data.test
-  #   algorithm = "lr"
-  #   model = model
-  #   new.factors = "exclude"
+#
+#   formula = x$formula
+#   data.train = x$data$train
+#   data.test = x$data$test
+#   algorithm = "lr"
+#   model = NULL
+#
 
   if(is.null(formula)) {stop("You must enter a valid formula")}
   if(is.null(algorithm)) {stop("You must specify one of the following models: 'rlr', 'lr', 'cart', 'svm', 'rf'")}
@@ -254,6 +259,7 @@ comp.pred <- function(formula,
     } else {train.mod <- model}
 
     if(is.null(data.train) == FALSE) {
+
       pred.train <- suppressWarnings(round(1 / (1 + exp(-predict(train.mod, data.train))), 0))
 
     } else {pred.train <- NULL}
@@ -316,6 +322,8 @@ comp.pred <- function(formula,
 
   # Get testing data
 
+  pred.test <- NULL
+
   if(is.null(data.test) == FALSE) {
 
     data.test <- data.all[test.cases, ]
@@ -381,21 +389,21 @@ comp.pred <- function(formula,
 
       if(is.null(data.test) == FALSE) {
 
+        pred.test <- rep(0, nrow(data.test))
+
         if(any(cannot.pred.v) & substr(new.factors, 1, 1) == "b") {
 
-          pred.test <- rep(0, nrow(data.test))
           pred.test[cannot.pred.v] <- mean(train.crit) > .5
           pred.test[cannot.pred.v == FALSE] <- round(1 / (1 + exp(-predict(train.mod, data.test[cannot.pred.v == FALSE,]))), 0)
 
         } else {
 
-          pred.test <- round(1 / (1 + exp(-predict(train.mod, data.test[cannot.pred.v == FALSE,]))), 0)
+          pred.test[!cannot.pred.v] <- round(1 / (1 + exp(-predict(train.mod, data.test[cannot.pred.v == FALSE,]))), 0)
 
         }
 
 
-      } else {pred.test <- NULL}
-
+      }
 
     }
 
@@ -418,67 +426,10 @@ comp.pred <- function(formula,
         }
 
 
-      } else {pred.test <- NULL}
+      }
 
     }
 
-    # if(algorithm == "rlr") {
-    #
-    #   # Set up training data with factor matrix
-    #
-    #   col.classes <- sapply(1:ncol(data.train), FUN = function(x) {class(data.train[,x])})
-    #   fact.names <- names(data.train)[col.classes == "factor"]
-    #   crit.name <- names(data.train)[1]
-    #
-    #   fact.formula <- as.formula(paste(crit.name, "~", paste(fact.names, collapse = "+")))
-    #   xfactors <- suppressWarnings(model.matrix(object = fact.formula, data = data.train)[,-1])
-    #   x.train <- suppressWarnings(as.matrix(data.frame(data.train[,col.classes %in% c("numeric", "integer", "logical")], xfactors))[,-1])
-    #
-    #   # Create new rLR model
-    #   train.mod <- try(train.mod <-  suppressWarnings(glmnet::cv.glmnet(x.train,
-    #                                                       y = as.factor(data.train[,1]),
-    #                                                       family = "binomial"
-    #   )), silent = TRUE)
-    #
-    #
-    #   if(class(train.mod) == "try-error") {
-    #
-    #     pred.train <- NULL
-    #
-    #     }
-    #
-    #   if(class(train.mod) == "cv.glmnet") {
-    #
-    #   pred.train <- round(as.vector(predict(train.mod,
-    #                                         x.train,
-    #                                         type = "response",
-    #                                         a = train.mod$lambda.min)), 0)
-    #
-    #  }
-    #
-    #   if(is.null(data.test) == FALSE & class(train.mod) == "cv.glmnet") {
-    #
-    #     # Set up test data with factor matrix
-    #
-    #     col.classes <- sapply(1:ncol(data.test), FUN = function(x) {class(data.test[,x])})
-    #     fact.names <- names(data.test)[col.classes == "factor"]
-    #     crit.name <- names(data.test)[1]
-    #
-    #     fact.formula <- as.formula(paste(crit.name, "~", paste(fact.names, collapse = "+")))
-    #     xfactors <- suppressWarnings(model.matrix(object = fact.formula, data = data.test)[,-1])
-    #     x.test <- suppressWarnings(as.matrix(data.frame(data.test[,col.classes %in% c("numeric", "integer", "logical")], xfactors))[,-1])
-    #
-    #     pred.test <- round(as.vector(predict(train.mod,
-    #                                          x.test,
-    #                                          type = "response",
-    #                                          a = train.mod$lambda.min)), 0)
-    #
-    #
-    #   } else {pred.test <- NULL}
-    #
-    #
-    # }
-
     if(algorithm == "cart") {
 
 
@@ -498,7 +449,7 @@ comp.pred <- function(formula,
 
 
 
-      } else {pred.test <- NULL}
+      }
 
 
     }
@@ -545,12 +496,10 @@ comp.pred <- function(formula,
         #
         # }
 
-
-
-      } else {pred.test <- NULL}
+      }
     }
 
-  } else {pred.test <- NULL}
+  }
 
   # Convert predictions to logical if necessary
 
@@ -561,8 +510,8 @@ comp.pred <- function(formula,
 
     # Calculate training accuracy stats
 
-    acc.train <- classtable(prediction.v = as.logical(pred.train),
-                            criterion.v = as.logical(crit.train))
+    acc.train <- classtable(prediction_v = as.logical(pred.train),
+                            criterion_v = as.logical(crit.train))
 
   }
 
@@ -573,18 +522,18 @@ comp.pred <- function(formula,
 
   }
 
-  if( is.null(pred.test) == FALSE) {
+  if(is.null(pred.test) == FALSE) {
 
     if("TRUE" %in% paste(pred.test)) {pred.test <- as.logical(paste(pred.test))}
     if("1" %in% paste(pred.test)) {pred.test <- as.logical(as.numeric(paste(pred.test)))}
 
 
-    acc.test <- classtable(prediction.v = as.logical(pred.test),
-                           criterion.v =  as.logical(crit.test))
+    acc.test <- classtable(prediction_v = as.logical(pred.test),
+                                    criterion_v =  as.logical(crit.test))
   } else {
 
-    acc.test <- classtable(prediction.v = c(TRUE, FALSE, TRUE),
-                           criterion.v = c(TRUE, TRUE, FALSE))
+    acc.test <- classtable(prediction_v = c(TRUE, FALSE, TRUE),
+                                     criterion_v = c(TRUE, TRUE, FALSE))
     acc.test[1,] <- NA
 
   }
@@ -601,13 +550,7 @@ comp.pred <- function(formula,
 
   # ORGANIZE
 
-  names(acc.train) <- paste(names(acc.train), ".train", sep = "")
-  names(acc.test) <- paste(names(acc.test), ".test", sep = "")
-
-  acc <- cbind(acc.train, acc.test)
-  acc <- acc[order(acc$spec.train),]
-
-  output <- list("accuracy" = acc,
+  output <- list("accuracy" = list(train = acc.train, test = acc.test),
                  "model" = train.mod,
                  "algorithm" = algorithm)
 
@@ -663,3 +606,362 @@ factclean <- function(
 
 }
 
+#' Adds decision statistics to a dataframe containing hr, cr, mi and fa
+#'
+#' @param data dataframe. With named (integer) columns hi, cr, mi, fa
+#' @param sens.w numeric. Sensitivity weight
+#' @param cost.each numeric. An optional fixed cost added to all outputs (e.g.; the cost of the cue)
+#' @param cost.outcomes list. A list of length 4 with names 'hi', 'fa', 'mi', and 'cr' specifying the costs of a hit, false alarm, miss, and correct rejection rspectively. E.g.; \code{cost.outcomes = listc("hi" = 0, "fa" = 10, "mi" = 20, "cr" = 0)} means that a false alarm and miss cost 10 and 20 respectively while correct decisions have no cost.
+Add_Stats <- function(data,
+                      sens.w = .5,
+                      cost.each = NULL,
+                      cost.outcomes = list(hi = 0, fa = 1, mi = 1, cr = 0)) {
+
+  if(is.null(cost.each)) {cost.each <- 0}
+
+  # Accuracy
+  data$acc <- with(data, (hi + cr) / (hi + cr + fa + mi))
+
+  # Sensitivity
+  data$sens <- with(data, hi / (hi + mi))
+
+  # Specificity
+  data$spec <- with(data, cr / (cr + fa))
+
+  # Negative Predictive Value
+  data$npv <- with(data, cr / (cr + mi))
+
+  # Positive Predictive Value
+  data$ppv <- with(data, hi / (hi + fa))
+
+  # False alarm rate
+  data$far <- with(data, 1 - spec)
+
+  # Balanced Accuracy
+  data$bacc <- with(data, sens * .5 + spec * .5)
+
+  # Weighted Accuracy
+  data$wacc <- with(data, sens * sens.w + spec * (1 - sens.w))
+
+  # Outcome Cost
+  data$cost_decisions <- with(data, -1 * (hi * cost.outcomes$hi + fa * cost.outcomes$fa + mi * cost.outcomes$mi + cr * cost.outcomes$cr)) / data$n
+
+  # Total Cost
+  data$cost <- data$cost_decisions - cost.each
+
+  # reorder
+  data <- data[, c("sens", "spec", "far", "ppv", "npv", "acc", "bacc", "wacc", "cost_decisions", "cost")]
+
+  return(data)
+
+}
+
+
+#' Calculates several classification statistics from binary prediction and criterion (e.g.; truth) vectors
+#' @param prediction_v logical. A logical vector of predictions
+#' @param criterion_v logical A logical vector of criterion (true) values
+#' @param sens.w numeric. Weight given to sensitivity, must range from 0 to 1.
+#' @param cost.v list. An optional list of additional costs to be added to each case.
+#' @param correction numeric. Correction added to all counts for calculating dprime
+#' @param cost.outcomes list. A list of length 4 with names 'hi', 'fa', 'mi', and 'cr' specifying the costs of a hit, false alarm, miss, and correct rejection rspectively. E.g.; \code{cost.outcomes = listc("hi" = 0, "fa" = 10, "mi" = 20, "cr" = 0)} means that a false alarm and miss cost 10 and 20 respectively while correct decisions have no cost.
+#' @param na_prediction_action not sure.
+#' @importFrom stats qnorm
+#' @importFrom caret confusionMatrix
+
+classtable <- function(prediction_v = NULL,
+                       criterion_v,
+                       sens.w = .5,
+                       cost.v = NULL,
+                       correction = .25,
+                       cost.outcomes = list(hi = 0, fa = 1, mi = 1, cr = 0),
+                       na_prediction_action = "ignore") {
+  #
+  #
+  #   prediction_v <- sample(c(TRUE, FALSE), size = 20, replace = TRUE)
+  #   criterion_v <- sample(c(TRUE, FALSE), size = 20, replace = TRUE)
+  #   sens.w = .5
+  #   cost.v = NULL
+  #   correction = .25
+  #   cost.outcomes = list(hi = 0, fa = 1, mi = 1, cr = 0)
+
+  if(is.null(cost.v)) {cost.v <- rep(0, length(prediction_v))}
+
+  if(any(c("FALSE", "TRUE") %in% paste(prediction_v))) {
+
+    prediction_v <- as.logical(paste(prediction_v))
+
+  }
+
+  if(any(c("FALSE", "TRUE") %in% paste(criterion_v))) {
+
+    criterion_v <- as.logical(paste(criterion_v))
+
+  }
+
+  if(((class(prediction_v) != "logical") | class(criterion_v) != "logical") & !is.null(prediction_v)) {stop("prediction_v and criterion_v must be logical")}
+
+
+
+  # Remove NA criterion values
+  prediction_v <- prediction_v[is.finite(criterion_v)]
+  criterion_v <- criterion_v[is.finite(criterion_v)]
+
+  # Remove NA prediction values
+
+  # if(na_prediction_action == "ignore") {
+  #
+  #   bad_index <- !is.finite(prediction_v)
+  #
+  #   prediction_v <- prediction_v[-bad_index]
+  #   criterion_v <- criterion_v[-bad_index]
+  #
+  #
+  # }
+
+  N <- min(length(criterion_v), length(prediction_v))
+
+  if(N > 0) {
+
+    if(var(prediction_v) > 0 & var(criterion_v) > 0) {
+
+
+      if(length(prediction_v) != length(criterion_v)) {
+
+        stop("length of prediction_v is", length(prediction_v), "and length of criterion_v is ",
+             length(criterion_v))
+      }
+
+      cm <- caret::confusionMatrix(table(prediction_v, criterion_v),
+                                   positive = "TRUE")
+
+      cm_byClass <- data.frame(as.list(cm$byClass))
+      cm_overall <- data.frame(as.list(cm$overall))
+
+      hi <- cm$table[2, 2]
+      mi <- cm$table[1, 2]
+      fa <- cm$table[2, 1]
+      cr <- cm$table[1, 1]
+
+      # Corrected values
+      hi_c <- hi + correction
+      mi_c <- mi + correction
+      fa_c <- fa + correction
+      cr_c <- cr + correction
+
+      # Statistics
+      sens <- cm_byClass$Sensitivity
+      spec <- cm_byClass$Specificity
+      far <- 1 - spec
+      acc <-  cm_overall$Accuracy
+      acc_p <- cm_overall$AccuracyPValue
+      ppv <- cm_byClass$Pos.Pred.Value
+      npv <- cm_byClass$Neg.Pred.Value
+      bacc <- cm_byClass$Balanced.Accuracy
+      wacc <- cm_byClass$Sensitivity * sens.w + cm_byClass$Specificity * (1 - sens.w)
+      dprime <- qnorm(hi_c / (hi_c + mi_c)) - qnorm(cr_c / (cr_c + fa_c))
+
+      # cost per case
+      cost_decisions <- (as.numeric(c(hi, fa, mi, cr) %*% c(cost.outcomes$hi, cost.outcomes$fa, cost.outcomes$mi, cost.outcomes$cr))) / N
+      cost <- (as.numeric(c(hi, fa, mi, cr) %*% c(cost.outcomes$hi, cost.outcomes$fa, cost.outcomes$mi, cost.outcomes$cr)) + sum(cost.v)) / N
+
+      # auc
+      #
+      #     auc <- as.numeric(pROC::roc(response = as.numeric(criterion_v),
+      #                                 predictor = as.numeric(prediction_v))$auc)
+
+    } else {
+
+      hi <- sum(prediction_v == TRUE & criterion_v == TRUE)
+      mi <- sum(prediction_v == FALSE & criterion_v == TRUE)
+      fa <- sum(prediction_v == TRUE & criterion_v == FALSE)
+      cr <- sum(prediction_v == FALSE & criterion_v == FALSE)
+
+      # Corrected values
+      hi_c <- hi + correction
+      mi_c <- mi + correction
+      fa_c <- fa + correction
+      cr_c <- cr + correction
+
+      # Statistics
+      sens <- hi / (hi + mi)
+      spec <- cr / (cr + fa)
+      far <- 1 - spec
+      acc <-  (hi + cr) / c(hi + cr + mi + fa)
+      acc_p <- NA
+      ppv <- hi / (hi + fa)
+      npv <- cr / (cr + mi)
+      bacc <- sens * .5 + spec * .5
+      wacc <- sens * sens.w + spec * (1 - sens.w)
+      dprime <- qnorm(hi_c / (hi_c + mi_c)) - qnorm(cr_c / (cr_c + fa_c))
+
+      # cost per case
+      cost_decisions <- (as.numeric(c(hi, fa, mi, cr) %*% c(cost.outcomes$hi, cost.outcomes$fa, cost.outcomes$mi, cost.outcomes$cr))) / N
+      cost <- (as.numeric(c(hi, fa, mi, cr) %*% c(cost.outcomes$hi, cost.outcomes$fa, cost.outcomes$mi, cost.outcomes$cr)) + sum(cost.v)) / N
+
+      # auc
+      # auc <- as.numeric(pROC::roc(response = as.numeric(criterion_v),
+      #                             predictor = as.numeric(prediction_v))$auc)
+
+    }
+
+  } else {
+
+    hi <- NA
+    mi <- NA
+    fa <- NA
+    cr <- NA
+    sens <- NA
+    spec <- NA
+    far <- NA
+    ppv <- NA
+    npv <- NA
+    far <- NA
+    acc <- NA
+    acc_p <- NA
+    bacc <- NA
+    wacc <- NA
+    dprime <- NA
+    cost_decisions <- NA
+    cost <- NA
+    # auc <- NA
+
+  }
+
+  result <- data.frame(
+    n = N,
+    hi = hi,
+    mi = mi,
+    fa = fa,
+    cr = cr,
+    sens = sens,
+    spec = spec,
+    far = far,
+    ppv = ppv,
+    npv = npv,
+    acc = acc,
+    acc_p = acc_p,
+    # auc = auc,
+    bacc = bacc,
+    wacc = wacc,
+    dprime = dprime,
+    cost_decisions = cost_decisions,
+    cost = cost)
+
+  return(result)
+
+}
+
+console_confusionmatrix <- function(hi, mi, fa, cr, cost) {
+#
+# hi <- 6534
+# mi <- 5
+# fa <- 765
+# cr <- 54
+#   cost <- 0
+#
+
+num_space <- function(x) {
+
+  if(x == 0) {return(1)}
+
+  ceiling(log10(x)) + floor(log(x, base = 1000))
+
+  }
+
+col_width <- max(c(8, floor(log10(max(c(hi, mi, fa, cr)))) + floor(log(max(c(hi, mi, fa, cr)), base = 1000)) + 6))
+
+# Header Row
+cat("|", rep(" ", times = 9),
+    "| True +",
+    rep(" ", col_width - 7),
+    "| True -",
+    rep(" ", col_width - 7),
+    "|\n", sep = "")
+
+# Line
+cat("|", rep("-", times = 9), "|", rep("-", times = col_width), "|", rep("-", times = col_width), "|\n", sep = "")
+
+# Decide + Row
+cat("|Decide +",
+  " ",
+    "| ",
+    crayon::silver("hi "),
+    crayon::green(scales::comma(hi)),
+    rep(" ", max(0, col_width - num_space(hi) - 4)),
+    "| ",
+    crayon::silver("fa "),
+    crayon::red(scales::comma(fa)),
+    rep(" ", max(0, col_width - num_space(fa) - 4)),
+    "| ", sep = "")
+cat(scales::comma(hi + fa))
+
+cat("\n")
+
+
+# Decide - Row
+cat("|Decide -",
+    " ",
+    "| ",
+    crayon::silver("mi "),
+    crayon::red(scales::comma(mi)),
+    rep(" ", max(0, col_width - num_space(mi) - 4)),
+    "| ",
+    crayon::silver("cr "),
+    crayon::green(scales::comma(cr)),
+    rep(" ", max(0, col_width - num_space(cr) - 4)),
+    "| ", sep = "")
+cat(scales::comma(mi + cr))
+cat("\n")
+
+# Bottom line
+cat("|-", rep("-", times = 8), "|", rep("-", times = col_width), "|", rep("-", times = col_width), "|\n", sep = "")
+
+# Bottom total
+cat(rep(" ", times = 12), sep = "")
+cat(scales::comma(hi + mi))
+cat(rep(" ", times = col_width - num_space(hi + mi)), " ", sep = "")
+cat(scales::comma(cr + fa))
+
+cat(rep(" ", col_width - num_space(cr + fa) + 1), sep = "")
+cat("N = ")
+cat(crayon::underline(scales::comma(hi + mi + fa + cr), sep = ""), sep = "")
+cat("\n\n")
+
+cat("acc  =", scales::percent((hi + cr) / (hi + mi + cr + fa), accuracy = .1), sep = " ")
+
+cat("  ppv  =", scales::percent(hi / (hi + fa), accuracy = .1), sep = " ")
+cat("  npv  =", scales::percent(cr / (cr + mi), accuracy = .1), sep = " ")
+cat("\n")
+
+cat("bacc =", scales::percent((hi / (hi + mi) + cr / (cr + fa)) / 2, accuracy = .1), sep = " ")
+
+cat("  sens =", scales::percent(hi / (hi + mi), accuracy = .1), sep = " ")
+cat("  spec =", scales::percent(cr / (cr + fa), accuracy = .1), sep = " ")
+cat("\n")
+cat("E(cost) =", scales::comma(cost, accuracy = .001), sep = " ")
+
+# cat("br   =", scales::percent((hi + mi) / (hi + cr + mi + fa), accuracy = .1), sep = " ")
+# cat("\n")
+
+}
+
+
+#' \code{FFTrees} package
+#'
+#' Create fast and frugal trees
+#'
+#' @docType package
+#' @name FFTrees
+#' @importFrom dplyr %>%
+NULL
+
+## quiets concerns of R CMD check re: the .'s that appear in pipelines
+if(getRversion() >= "2.15.1")  utils::globalVariables(c(".", "tree", "tree_new", "tree", "level"))
+
+
+
+
+
+
+
+
